import { TTraining } from '../types'
import { calculateRating } from '../utils'
import { useContext } from 'react'
import { UserContext } from '../../user/hooks'
import { useRegisterMutation } from '../../gql'

const TrainingMeta = ({ training }: { training: TTraining }) => {
  const { user } = useContext(UserContext)
  const [register, registerData] = useRegisterMutation({
    variables: { training: training.id }
  })

  return (
    <aside>
      <div className='info'>
        <span className='caption'>Type: </span>
        <span className='data'>{training.type.name}</span>
      </div>
      <div className='info'>
        <span className='caption'>Date: </span>
        <span className='data'>
          {new Date(training.trainingDate).toLocaleString()}
        </span>
      </div>
      <div className='info'>
        <span className='caption'>Location: </span>
        <span className='data'>{training.location}</span>
      </div>
      <div className='info'>
        <span className='caption'>Registrations: </span>
        <span className='data'>{training.registrations?.length ?? 0}</span>
        {training.registrations &&
        training.registrations.find(
          registeredUser =>
            user?.data?.currentUser &&
            registeredUser.id === user.data.currentUser.id
        ) ? (
          <button onClick={() => register()}>Deregister</button>
        ) : (
          <button onClick={() => register()}>Register now!</button>
        )}
      </div>
      {/*<div className="info">
        <span className="caption">Attendance: </span>
        <span className="data">{training.attendance}</span>
      </div>
      <div className="info">
        <span className="caption">Rating: </span>
        <span className="data">
          {calculateRating(training.ratings)} [
          <a href="">{training.ratings.length}</a>] Rate it!
          <a href="">*</a>
          <a href="">*</a>
          <a href="">*</a>
          <a href="">*</a>
          <a href="">*</a>
        </span>
      </div>
          */}

      <style jsx>{`
        aside {
          grid-area: information;
          background: rgba(200, 200, 200, 0.8);
          min-height: 370px;
          padding: 0.2em 1em;
          margin: 0;
        }
        .info .caption {
          font-weight: 900;
          display: inline-block;
          min-width: 7em;
        }
      `}</style>
    </aside>
  )
}

export default TrainingMeta
